/**
 * Returns a new function that, when invoked, invokes `fn` at most once per `wait` milliseconds.
 *
 * @see https://github.com/component/throttle/blob/master/index.js
 * @see https://github.com/mqyqingfeng/Blog/issues/26
 *
 * @param {Function} function to wrap
 * @param {Number} wait Number of milliseconds that must elapse between `fn` invocations.
 * @return {Function} function that wraps the `fn` function passed in.
 */
export declare function throttle<T extends any[], R>(fn: (...args: T) => R, wait: number): (...args: T) => R;
export default throttle;
